package be.iminds.ilabt.jfed.highlevel.tasks;

import be.iminds.ilabt.jfed.highlevel.controller.Task;
import be.iminds.ilabt.jfed.highlevel.controller.TaskExecution;
import be.iminds.ilabt.jfed.highlevel.model.Slice;
import be.iminds.ilabt.jfed.highlevel.util.AggregateManagerWrapperFactory;
import be.iminds.ilabt.jfed.lowlevel.JFedException;
import be.iminds.ilabt.jfed.lowlevel.api_wrapper.AggregateManagerWrapper;
import be.iminds.ilabt.jfed.fedmon.webapi.service.json.*;

import javax.annotation.Nonnull;
import java.util.Collections;
import java.util.List;

/**
 * User: twalcari
 * Date: 6/17/2015
 * Time: 16:41
 */
public class ShareLanTask extends Task {
    @Nonnull private final String lanClientId;
    @Nonnull private final String newSharedLanName;
    @Nonnull private final Server auth;
    @Nonnull private final Slice slice;

    @Nonnull private final AggregateManagerWrapperFactory aggregateManagerWrapperFactory;
    @Nonnull private final HighLevelTaskFactory highLevelTaskFactory;

    public ShareLanTask(@Nonnull Slice slice,
                        @Nonnull Server auth,
                        @Nonnull String lanClientId,
                        @Nonnull String newSharedLanName,
                        @Nonnull AggregateManagerWrapperFactory aggregateManagerWrapperFactory,
                        @Nonnull HighLevelTaskFactory highLevelTaskFactory) {
        super("Share Lan " + lanClientId + " as " + newSharedLanName);
        this.lanClientId = lanClientId;
        this.newSharedLanName = newSharedLanName;
        this.auth = auth;
        this.slice = slice;
        this.aggregateManagerWrapperFactory = aggregateManagerWrapperFactory;
        this.highLevelTaskFactory = highLevelTaskFactory;
    }

    @Override
    public void doTask(@Nonnull TaskExecution taskExecution) throws JFedException, InterruptedException {
        AggregateManagerWrapper amWrapper =
                aggregateManagerWrapperFactory.getAggregateManagerWrapper(taskExecution, auth);
        amWrapper.shareLan(slice.getUrn(), slice.getCredentials(), lanClientId, newSharedLanName);
    }

    @Nonnull
    @Override
    public List<Task> initDependsOn() {
        return Collections.singletonList(highLevelTaskFactory.getSliceCredential(slice));
    }
}
